﻿-- =====================================================
-- Tanév létrehozásakor a tanév rendje eseményeg
-- insertje és az első és utolsó tanítási napok
-- update-je a T_TANEV táblában
--
-- Az újabb tanév mindig előre kerüljön (Csabi kérése)
-- =====================================================
-- 1389  Egész napos kirándulás
-- 1400  Első félév vége
-- 7605  Első félév vége (keresztféléves képzésben)
-- 1394  Első tanítási nap
-- 7604  Első tanítási nap (keresztféléves képzésben)
-- 1390  Fogadónap (tanítás nélküli)
-- 1403  I. negyedév vége
-- 1404  III. negyedév vége
-- 1386  Munkaszüneti nap
-- 1406  Nyári oktatási nap
-- 1405  Nyári szakmai gyakorlati nap
-- 1649  Nyílt nap
-- 1405  Összefüggő szakmai gyakorlati nap
-- 1399  Őszi szünet
-- 6833  Pihenőnap
-- 1406  Rendkívüli tanítási nap
-- 1393  Rövidített órákat tartalmazó tanítási nap
-- 1391  Szabadnap (intézményvezetői hatáskörben)
-- 1388  Szülői értekezlet (tanítás nélkül)
-- 1387  Tanítás nélküli munkanap
-- 1385  Tanítási nap
-- 1392  Tanítási szünet
-- 1398  Tavaszi szünet
-- 1397  Téli szünet
-- 1395  Utolsó tanítási nap
-- 1402  Utolsó tanítási nap a végzős évfolyamokon
-- 7601  Utolsó tanítási nap a végzős évfolyamokon (honvédelmi iskolákban)
-- 7602  Utolsó tanítási nap a végzős évfolyamokon (keresztféléves képzésben)
-- 7600  Utolsó tanítási nap a végzős évfolyamokon (rendészeti iskolákban)
-- 7603  Utolsó tanítási nap a végzős évfolyamokon (részszakképesítéses oktatásban)
-- 1396  Ünnepnap
-- 1401  Vizsganap

-- 1408  Hétfő
-- 1409  Kedd
-- 1410  Szerda
-- 1411  Csütörtök
-- 1412  Péntek
-- 1413  Szombat
-- 1414  Vasárnap

DROP PROCEDURE IF EXISTS dev.uspCreateTanevRendje
GO

CREATE PROCEDURE dev.uspCreateTanevRendje
   @intezmenyId int
  ,@tanevId int
  ,@hetNapjaTipusTypeId int = 40
AS BEGIN  
  SET NOCOUNT ON;
  SET DATEFIRST 1;
  
  DECLARE 
     @tanevNev nvarchar(20)
    ,@elsoTanitasiNap datetime
    ,@utolsoTanitasiNap datetime
    
  SELECT @tanevNev = C_NEV 
  FROM T_TANEV 
  WHERE ID = @tanevId
   

  IF @tanevNev = '2022/2023' BEGIN
    
    SET @elsoTanitasiNap   = '20220901'
    SET @utolsoTanitasiNap = '20230615'
   
    INSERT  dbo.T_TANEVRENDJE (
      C_AKTIV, C_DATUM, C_HETIREND, C_HETNAPJA, C_MEGJEGYZES, C_NAPTIPUSA, C_ORARENDINAP, C_OSSZESCSOPORTRAVONATKOZIK, C_CSENGETESIRENDID, C_INTEZMENYID, C_TANEVID, TOROLT, SERIAL, LASTCHANGED, CREATED, MODIFIER, CREATOR
    ) VALUES

--  az első tanítási nap, ezt már előre fel kell venni, amikor a kiválasztható tanévet létrehozzuk!!!
       ('T', @elsoTanitasiNap, 1554, dbo.fnGetHetNapja(@elsoTanitasiNap, @hetNapjaTipusTypeId), N'', 1394, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)

--  október 23-i ünnepnap (és lehet előtte vagy utána egy pihenőnap)
      ,('T', '20221023', 1554, dbo.fnGetHetNapja('20221023', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
--  november 1-i munkaszüneti nap (és lehet előtte vagy utána egy pihenőnap)
      ,('T', '20221031', 1554, dbo.fnGetHetNapja('20221031', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221101', 1554, dbo.fnGetHetNapja('20221101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  az őszi szünet napjai     
      ,('T', '20221102', 1554, dbo.fnGetHetNapja('20221102', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221103', 1554, dbo.fnGetHetNapja('20221103', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221104', 1554, dbo.fnGetHetNapja('20221104', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
    
--  a téli szünet napjai  
      ,('T', '20221222', 1554, dbo.fnGetHetNapja('20221222', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221223', 1554, dbo.fnGetHetNapja('20221223', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221227', 1554, dbo.fnGetHetNapja('20221227', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221228', 1554, dbo.fnGetHetNapja('20221228', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221229', 1554, dbo.fnGetHetNapja('20221229', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221230', 1554, dbo.fnGetHetNapja('20221230', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20230102', 1554, dbo.fnGetHetNapja('20230102', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  december 24-i pihenőnap; Karácsony munkaszüneti napjai, Január 1-i munaszüneti nap
      ,('T', '20221224', 1554, dbo.fnGetHetNapja('20221224', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221225', 1554, dbo.fnGetHetNapja('20221225', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20221226', 1554, dbo.fnGetHetNapja('20221226', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20230101', 1554, dbo.fnGetHetNapja('20230101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  az első félév utolsó tanítási napja      
      ,('T', '20230120', 1554, dbo.fnGetHetNapja('20230120', @hetNapjaTipusTypeId), N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  március 15-i ünnepnap (és lehet előtte vagy utána egy pihenőnap)
      ,('T', '20230315', 1554, dbo.fnGetHetNapja('20230315', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      
--  a tavaszi szünet napjai
      ,('T', '20230406', 1554, dbo.fnGetHetNapja('20230406', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20230411', 1554, dbo.fnGetHetNapja('20230411', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      
--  a Húsvét munkaszüneti napjai
      ,('T', '20230407', 1554, dbo.fnGetHetNapja('20230407', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20230409', 1554, dbo.fnGetHetNapja('20230409', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20230410', 1554, dbo.fnGetHetNapja('20230410', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      
--  május 1-i munkaszüneti nap (és lehet előtte vagy utána egy pihenőnap)
      ,('T', '20230501', 1554, dbo.fnGetHetNapja('20230501', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  a pünkösd hétfői munkaszüneti nap      
      ,('T', '20230529', 1554, dbo.fnGetHetNapja('20230529', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  az utolsó tanítási nap a végzős évfolyamokon     
      ,('T', '20230504', 1554, dbo.fnGetHetNapja('20230504', @hetNapjaTipusTypeId), N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

--  az utolsó tanítási nap, ezt már előre fel kell venni, amikor a kiválasztható tanévet létrehozzuk!!!
      ,('T', @utolsoTanitasiNap, 1554, dbo.fnGetHetNapja(@utolsoTanitasiNap, @hetNapjaTipusTypeId), N'', 1395, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)

  END

  IF @tanevNev = '2021/2022' BEGIN
    SET @elsoTanitasiNap = '20210901'
    SET @utolsoTanitasiNap = '20220615'
    INSERT  dbo.T_TANEVRENDJE (
      C_AKTIV, C_DATUM, C_HETIREND, C_HETNAPJA, C_MEGJEGYZES, C_NAPTIPUSA, C_ORARENDINAP, C_OSSZESCSOPORTRAVONATKOZIK, C_CSENGETESIRENDID, C_INTEZMENYID, C_TANEVID, TOROLT, SERIAL, LASTCHANGED, CREATED, MODIFIER, CREATOR
    ) VALUES
       ('T', @elsoTanitasiNap, 1554, 1410, N'', 1394, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)

    -- Okt. 23., Nov. 1. (1396-Ünnepnap; 1386-Munkaszüneti nap)
      ,('T', '20211023', 1554, dbo.fnGetHetNapja('20211023', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211101', 1554, dbo.fnGetHetNapja('20211101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Őszi szünet (1399-Őszi szünet)                                              
      ,('T', '20211025', 1554, dbo.fnGetHetNapja('20211025', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211026', 1554, dbo.fnGetHetNapja('20211026', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211027', 1554, dbo.fnGetHetNapja('20211027', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211028', 1554, dbo.fnGetHetNapja('20211028', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211029', 1554, dbo.fnGetHetNapja('20211029', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Téli szünet (1397-Téli szünet)                                                        
      ,('T', '20211222', 1554, dbo.fnGetHetNapja('20211222', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211223', 1554, dbo.fnGetHetNapja('20211223', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211227', 1554, dbo.fnGetHetNapja('20211227', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211228', 1554, dbo.fnGetHetNapja('20211228', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211229', 1554, dbo.fnGetHetNapja('20211229', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211230', 1554, dbo.fnGetHetNapja('20211230', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211231', 1554, dbo.fnGetHetNapja('20211231', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Karacsony, újév (6833-Pihenőnap; 1386-Munkaszüneti nap)
      ,('T', '20211224', 1554, dbo.fnGetHetNapja('20211224', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211225', 1554, dbo.fnGetHetNapja('20211225', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20211226', 1554, dbo.fnGetHetNapja('20211226', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20220101', 1554, dbo.fnGetHetNapja('20220101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Első félév vége (1400-Első félév vége)  
      ,('T', '20220121', 1554, dbo.fnGetHetNapja('20220121', @hetNapjaTipusTypeId), N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Márc. 15. (6833-Pihenőnap; 1396-Ünnepnap)
      ,('T', '20220314', 1554, dbo.fnGetHetNapja('20220314', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20220315', 1554, dbo.fnGetHetNapja('20220315', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Tavaszi szünet (1398-Tavaszi szünet)
      ,('T', '20220414', 1554, dbo.fnGetHetNapja('20220414', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20220419', 1554, dbo.fnGetHetNapja('20220419', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Húsvét (1386-Munkaszüneti nap)
      ,('T', '20220415', 1554, dbo.fnGetHetNapja('20220415', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20220417', 1554, dbo.fnGetHetNapja('20220417', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20220418', 1554, dbo.fnGetHetNapja('20220418', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Május 1. (1386-Munkaszüneti nap)
      ,('T', '20220501', 1554, dbo.fnGetHetNapja('20220501', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Pünkösdhétfő (1386-Munkaszüneti nap)
      ,('T', '20220606', 1554, dbo.fnGetHetNapja('20220606', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Utcsó tanítási nap - végzős (1402-Utolsó tanítási nap a végzős évfolyamokon)
      ,('T', '20220429', 1554, dbo.fnGetHetNapja('20220429', @hetNapjaTipusTypeId), N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)

      ,('T', @utolsoTanitasiNap, 1554, 1410, N'', 1395, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
  END
  IF @tanevNev = '2020/2021' BEGIN
    SET @elsoTanitasiNap = '20200901'
    SET @utolsoTanitasiNap = '20210615'
    INSERT  dbo.T_TANEVRENDJE (
      C_AKTIV, C_DATUM, C_HETIREND, C_HETNAPJA, C_MEGJEGYZES, C_NAPTIPUSA, C_ORARENDINAP, C_OSSZESCSOPORTRAVONATKOZIK, C_CSENGETESIRENDID, C_INTEZMENYID, C_TANEVID, TOROLT, SERIAL, LASTCHANGED, CREATED, MODIFIER, CREATOR
    ) VALUES
       ('T', @elsoTanitasiNap, 1554, 1409, N'', 1394, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
       -- Okt. 23., Nov. 1.
      ,('T', '20201023', 1554, dbo.fnGetHetNapja('20201023', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201101', 1554, dbo.fnGetHetNapja('20201101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      --Őszi szüret                                                            
      ,('T', '20201026', 1554, dbo.fnGetHetNapja('20201026', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201027', 1554, dbo.fnGetHetNapja('20201027', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201028', 1554, dbo.fnGetHetNapja('20201028', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201029', 1554, dbo.fnGetHetNapja('20201029', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201030', 1554, dbo.fnGetHetNapja('20201030', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      --Téli szünet                                                           
      ,('T', '20201221', 1554, dbo.fnGetHetNapja('20201221', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201222', 1554, dbo.fnGetHetNapja('20201222', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201223', 1554, dbo.fnGetHetNapja('20201223', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201228', 1554, dbo.fnGetHetNapja('20201228', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201229', 1554, dbo.fnGetHetNapja('20201229', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201230', 1554, dbo.fnGetHetNapja('20201230', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201231', 1554, dbo.fnGetHetNapja('20201231', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      --Karacsony, újév
      ,('T', '20201224', 1554, dbo.fnGetHetNapja('20201224', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201225', 1554, dbo.fnGetHetNapja('20201225', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20201226', 1554, dbo.fnGetHetNapja('20201226', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20210101', 1554, dbo.fnGetHetNapja('20210101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      --  Első félév vége  
      ,('T', '20210122', 1554, dbo.fnGetHetNapja('20210122', @hetNapjaTipusTypeId), N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Márc. 15.
      ,('T', '20210315', 1554, dbo.fnGetHetNapja('20210315', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Tavaszi szünet
      ,('T', '20210401', 1554, dbo.fnGetHetNapja('20210401', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20210406', 1554, dbo.fnGetHetNapja('20210406', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Húsvét
      ,('T', '20210402', 1554, dbo.fnGetHetNapja('20210402', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20210404', 1554, dbo.fnGetHetNapja('20210404', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      ,('T', '20210405', 1554, dbo.fnGetHetNapja('20210405', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Május 1.
      ,('T', '20210501', 1554, dbo.fnGetHetNapja('20210501', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      --Pünkösdhétfő
      ,('T', '20210524', 1554, dbo.fnGetHetNapja('20210524', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      -- Utcsó tanítási nap - végzős
      ,('T', '20210430', 1554, dbo.fnGetHetNapja('20210430', @hetNapjaTipusTypeId), N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 0)
      
      ,('T', @utolsoTanitasiNap, 1554, 1408, N'', 1395, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
  END
  IF @tanevNev = '2019/2020' BEGIN
    SET @elsoTanitasiNap = '20190902'
    SET @utolsoTanitasiNap = '20200615'
    INSERT  dbo.T_TANEVRENDJE (
      C_AKTIV, C_DATUM, C_HETIREND, C_HETNAPJA, C_MEGJEGYZES, C_NAPTIPUSA, C_ORARENDINAP, C_OSSZESCSOPORTRAVONATKOZIK, C_CSENGETESIRENDID, C_INTEZMENYID, C_TANEVID, TOROLT, SERIAL, LASTCHANGED, CREATED, MODIFIER, CREATOR
    ) VALUES
       ('T', @elsoTanitasiNap, 1554, 1408, N'', 1394, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191023', 1554, dbo.fnGetHetNapja('20191023', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191028', 1554, dbo.fnGetHetNapja('20191028', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191029', 1554, dbo.fnGetHetNapja('20191029', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191030', 1554, dbo.fnGetHetNapja('20191030', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191031', 1554, dbo.fnGetHetNapja('20191031', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191101', 1554, dbo.fnGetHetNapja('20191101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191223', 1554, dbo.fnGetHetNapja('20191223', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191230', 1554, dbo.fnGetHetNapja('20191230', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191231', 1554, dbo.fnGetHetNapja('20191231', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200102', 1554, dbo.fnGetHetNapja('20200102', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200103', 1554, dbo.fnGetHetNapja('20200103', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191224', 1554, dbo.fnGetHetNapja('20191224', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191225', 1554, dbo.fnGetHetNapja('20191225', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20191226', 1554, dbo.fnGetHetNapja('20191226', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200101', 1554, dbo.fnGetHetNapja('20200101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200124', 1554, dbo.fnGetHetNapja('20200124', @hetNapjaTipusTypeId), N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200315', 1554, dbo.fnGetHetNapja('20200315', @hetNapjaTipusTypeId), N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200409', 1554, dbo.fnGetHetNapja('20200409', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200414', 1554, dbo.fnGetHetNapja('20200414', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200410', 1554, dbo.fnGetHetNapja('20200410', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200413', 1554, dbo.fnGetHetNapja('20200413', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200501', 1554, dbo.fnGetHetNapja('20200501', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200430', 1554, dbo.fnGetHetNapja('20200430', @hetNapjaTipusTypeId), N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', '20200601', 1554, dbo.fnGetHetNapja('20200601', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
      ,('T', @utolsoTanitasiNap, 1554, 1408, N'', 1395, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)
  END

  IF @tanevNev = '2018/2019' BEGIN
    SET @elsoTanitasiNap = '20180903'
    SET @utolsoTanitasiNap = '20190614'
    INSERT  dbo.T_TANEVRENDJE (
      C_AKTIV, C_DATUM, C_HETIREND, C_HETNAPJA, C_MEGJEGYZES, C_NAPTIPUSA, C_ORARENDINAP, C_OSSZESCSOPORTRAVONATKOZIK, C_CSENGETESIRENDID, C_INTEZMENYID, C_TANEVID, TOROLT, SERIAL, LASTCHANGED, CREATED, MODIFIER, CREATOR
    ) VALUES
      ('T', @elsoTanitasiNap, 1554, 1408, N'', 1394, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', @utolsoTanitasiNap, 1554, 1412, N'', 1395, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181013',  1554, 1408, N'', 1385, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181022',  1554, NULL, N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181023',  1554, NULL, N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181029',  1554, NULL, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181030',  1554, NULL, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181031',  1554, NULL, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181101',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181102',  1554, NULL, N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181110',  1554, 1412, N'', 1385, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181201',  1554, 1408, N'', 1385, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181215',  1554, 1408, N'', 1385, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181224',  1554, NULL, N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181225',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181226',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181227',  1554, NULL, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181228',  1554, NULL, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20181231',  1554, NULL, N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190101',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190102',  1554, NULL, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190125',  1554, 1412, N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190315',  1554, NULL, N'', 1396, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190418',  1554, NULL, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190419',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190422',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190423',  1554, NULL, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190501',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190502',  1554, 1411, N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL),
      ('T', '20190610',  1554, NULL, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, NULL)    
  END

  IF @tanevNev = '2017/2018' BEGIN
    SET @elsoTanitasiNap = '20170901'
    SET @utolsoTanitasiNap = '20180615'
    INSERT [dbo].[T_TANEVRENDJE] 
      ([C_AKTIV], [C_DATUM], [C_HETIREND], [C_HETNAPJA], [C_MEGJEGYZES], [C_NAPTIPUSA], [C_ORARENDINAP], [C_OSSZESCSOPORTRAVONATKOZIK], [C_CSENGETESIRENDID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [LASTCHANGED], [CREATED], [MODIFIER], [CREATOR]) 
    VALUES
      ('T', @elsoTanitasiNap, 1554, dbo.fnGetHetNapja('20170901', @hetNapjaTipusTypeId), N'', 1394, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171023', 1554, dbo.fnGetHetNapja('20171023', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171030', 1554, dbo.fnGetHetNapja('20171030', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171031', 1554, dbo.fnGetHetNapja('20171031', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171101', 1554, dbo.fnGetHetNapja('20171101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171102', 1554, dbo.fnGetHetNapja('20171102', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171103', 1554, dbo.fnGetHetNapja('20171103', @hetNapjaTipusTypeId), N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171225', 1554, dbo.fnGetHetNapja('20171225', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171226', 1554, dbo.fnGetHetNapja('20171226', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171227', 1554, dbo.fnGetHetNapja('20171227', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171228', 1554, dbo.fnGetHetNapja('20171228', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20171229', 1554, dbo.fnGetHetNapja('20171229', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180101', 1554, dbo.fnGetHetNapja('20180101', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180102', 1554, dbo.fnGetHetNapja('20180102', @hetNapjaTipusTypeId), N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180126', 1554, dbo.fnGetHetNapja('20180126', @hetNapjaTipusTypeId), N'', 1400, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180310', 1554, dbo.fnGetHetNapja('20180310', @hetNapjaTipusTypeId), N'', 1385, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180315', 1554, dbo.fnGetHetNapja('20180315', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180316', 1554, dbo.fnGetHetNapja('20180316', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180329', 1554, dbo.fnGetHetNapja('20180329', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180330', 1554, dbo.fnGetHetNapja('20180330', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180402', 1554, dbo.fnGetHetNapja('20180402', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180403', 1554, dbo.fnGetHetNapja('20180403', @hetNapjaTipusTypeId), N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180421', 1554, dbo.fnGetHetNapja('20180421', @hetNapjaTipusTypeId), N'', 1385, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180430', 1554, dbo.fnGetHetNapja('20180430', @hetNapjaTipusTypeId), N'', 6833, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180501', 1554, dbo.fnGetHetNapja('20180501', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180503', 1554, dbo.fnGetHetNapja('20180503', @hetNapjaTipusTypeId), N'', 1402, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', '20180521', 1554, dbo.fnGetHetNapja('20180521', @hetNapjaTipusTypeId), N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1),
      ('T', @utolsoTanitasiNap, 1554, dbo.fnGetHetNapja('20180615', @hetNapjaTipusTypeId), N'', 1395, 'T', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, GETDATE(), GETDATE(), NULL, 1)
  END

  IF @tanevNev = '2016/2017' BEGIN
    SET @elsoTanitasiNap = '20160901'
    SET @utolsoTanitasiNap = '20170615'
    INSERT [dbo].[T_TANEVRENDJE] (
      [C_AKTIV], [C_DATUM], [C_HETIREND], [C_HETNAPJA], [C_MEGJEGYZES], [C_NAPTIPUSA], [C_ORARENDINAP], [C_OSSZESCSOPORTRAVONATKOZIK], [C_CSENGETESIRENDID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [LASTCHANGED], [CREATED], [MODIFIER], [CREATOR]
    ) VALUES 
      ('T', @elsoTanitasiNap, 1554, 1407, N'', 1394, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161031', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161101', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161102', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161103', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161104', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161222', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161223', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161226', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161227', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161228', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161229', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20161230', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170120', 1554, 1407, N'', 1400, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170315', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170413', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170414', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170417', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170418', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170428', 1554, 1407, N'', 1402, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170501', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20170605', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', @utolsoTanitasiNap, 1554, 1407, N'', 1395, 'F', 'T', NULL, @intezmenyId, @tanevId, N'F', 0, NULL, GETDATE(), NULL, 1)
  END  

  IF @tanevNev = '2015/2016' BEGIN
    SET @elsoTanitasiNap = '20150901'
    SET @utolsoTanitasiNap = '20160615'
    INSERT [dbo].[T_TANEVRENDJE] (
      [C_AKTIV], [C_DATUM], [C_HETIREND], [C_HETNAPJA], [C_MEGJEGYZES], [C_NAPTIPUSA], [C_ORARENDINAP], [C_OSSZESCSOPORTRAVONATKOZIK], [C_CSENGETESIRENDID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [LASTCHANGED], [CREATED], [MODIFIER], [CREATOR]
    ) VALUES 
      ('T', @elsoTanitasiNap, 1554, 1407, N'', 1394, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151023', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151026', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151027', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151028', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151029', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151030', 1554, 1407, N'', 1399, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151101', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151221', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151222', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151223', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151224', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151225', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151226', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151228', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151229', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151230', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20151231', 1554, 1407, N'', 1397, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160101', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160122', 1554, 1407, N'', 1400, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160314', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160315', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160324', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160325', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160328', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160329', 1554, 1407, N'', 1398, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160429', 1554, 1407, N'', 1402, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160501', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', '20160516', 1554, 1407, N'', 1386, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1),
      ('T', @utolsoTanitasiNap, 1554, 1407, N'', 1395, 'F', 'T', NULL, @intezmenyId, @tanevId, 'F', 0, NULL, GETDATE(), NULL, 1)
  END

  UPDATE T_TANEV SET
     C_ELSOTANITASINAP = @elsoTanitasiNap
    ,C_UTOLSOTANITASINAP = @utolsoTanitasiNap
  WHERE ID = @tanevId

  EXEC sp_GenerateNaptariNapok @intezmenyId, @tanevId, 0, 40

END