﻿-- =============================================
-- Author:        Sólyom Péter
-- Create date: 2016.06.15.
-- Description:    A tanévhez tartozó alapadatokat és sémákat generálja le.
-- =============================================
DROP PROCEDURE IF EXISTS [dev].[uspGenerateTanevAdatok]
GO

CREATE PROCEDURE [dev].[uspGenerateTanevAdatok]
   @intezmenyId int
  ,@intezmenyAzonosito nvarchar(30)
  ,@tanevNeve nvarchar(20)
  ,@kovetkezoTanev bit
  ,@intezmenyNeve nvarchar(255)
  ,@intezmenyIranyitoSzam nvarchar(20)
  ,@intezmenyVaros nvarchar(255)
  ,@intezmenyKozteruletNev nvarchar(40)
  ,@intezmenyKozteruletJellegNev nvarchar(100)
  ,@intezmenyHazszam nvarchar(30)
  ,@intezmenyEmelet nvarchar(40)
  ,@intezmenyAjto nvarchar(30)
  ,@intezmenyOMKod nvarchar(20)
  ,@intezmenyIgazgato nvarchar(255)
  ,@intezmenyTagkod nvarchar(50)
  ,@intezmenyEmail nvarchar(255)
  ,@adminJelszo nvarchar(8)
  ,@kellABHet bit
  ,@teljesKreta bit
  ,@dbJelszo nvarchar(50)
AS
BEGIN
  SET NOCOUNT ON;
  DECLARE   
     @so nvarchar(64)
    ,@jelszoHash nvarchar(64)
    ,@tanevId INT
    
  --------------------------- TANÉV LÉTREHOZÁSA ---------------------------
  DECLARE @vanmasikTanev INT = (SELECT COUNT(1) FROM T_TANEV WHERE T_TANEV.C_INTEZMENYID = @intezmenyId) 
  INSERT INTO [dbo].[T_TANEV] (
     [C_AKTIV]
    ,[C_ELSOTANITASINAP]
    ,[C_KEZDONAP]
    ,[C_KOVETKEZO]
    ,[C_NEV]
    ,[C_SORSZAM]
    ,[C_UTOLSONAP]
    ,[C_UTOLSOTANITASINAP]
    ,[C_INTEZMENYID]
    ,[TOROLT]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR]
    ,[C_AKTIVALHATOSAGKEZDETE]
  ) VALUES (
     IIF(@vanmasikTanev = 0, 'T', 'F')
    ,SUBSTRING(@tanevNeve, 1, 4) + '0901'
    ,SUBSTRING(@tanevNeve, 1, 4) + '0901'
    ,IIF(@kovetkezoTanev = 1, 'T', 'F')
    ,@tanevNeve
    ,CAST(SUBSTRING(@tanevNeve, 3, 2) AS int) * 2 /*C_SSORSZAM a kezdő év utolsó két számjegye szorozva kettővel*/ 
    ,SUBSTRING(@tanevNeve, 6, 4) + '0831'
    ,SUBSTRING(@tanevNeve, 6, 4) + '0615'
    ,@intezmenyId
    ,'F'
    ,0
    ,GETDATE()
    ,GETDATE()
    ,NULL
    ,NULL
    ,NULL
  )
  
  PRINT @tanevNeve +' tanév létrehozása sikeres!';
  SET @tanevId = SCOPE_IDENTITY()

  UPDATE T_TANEV
  SET C_AKTIVALHATOSAGKEZDETE = DATEADD(DAY, -9, C_KEZDONAP)
  WHERE ID = @tanevId

  --------------------------- TANÉV LÉTREHOZÁSA VÉGE ---------------------------
  --------------------------- LICENCE LÉTREHOZÁSA ---------------------------
  INSERT INTO [dbo].[T_LICENCE] (
     [C_DATE]
    ,[C_FULL]
    ,[C_FUNCTION]
    ,[C_INTEZMENYID]
    ,[C_TANEVID]
  ) VALUES (
    SUBSTRING(@tanevNeve, 6, 4) + '0831'
    ,'T', 
    NULL, 
    @intezmenyId,
    @tanevId 
  )
  --------------------------- LICENCE LÉTREHOZÁSA VÉGE ---------------------------
  
  --------------------------- SZÓTÁRELEMEK LÉTREHOZÁSA ---------------------------
  DROP INDEX IF EXISTS [NCI_OktatasiNevelesiFeladat_AlintezmenyId_AltanevId_FeladatKategoriaId] ON T_OKTATASINEVELESIFELADAT
  ALTER TABLE T_OKTATASINEVELESIFELADAT ALTER COLUMN C_FELADATKATEGORIAID INT NULL

  EXEC [dev].[uspCreateDictionaryItems] @intezmenyId = @intezmenyId, @pTanevNev = @tanevNeve
  
  -- TODO ERTEKELES REFAKT2 ERTEKELESMOD: Ha töröljük a T_TANARIATLAGSULY táblát, akkor törölni kell a T_TANARIATLAGSULY-os INSERT INTO-t!
  -- https://jira.ekreta.hu/browse/KRETA2-12367
  INSERT INTO T_TANARIATLAGSULY (
     C_SULY
    ,C_ERTEKELESMODID
    ,C_INTEZMENYID
    ,C_TANEVID
    ,TOROLT
    ,SERIAL
    ,LASTCHANGED
    ,CREATED
    ,MODIFIER
    ,CREATOR
    ,ELOZOTANEVIREKORDID
  ) SELECT
     100 AS C_SULY -- * int
    ,d.ID AS C_ERTEKELESMODID -- * int
    ,d.C_ALINTEZMENYID AS C_INTEZMENYID -- * int
    ,d.C_ALTANEVID AS C_TANEVID -- * int
    ,'F' AS TOROLT -- * char(1)
    ,0 AS SERIAL -- * int
    ,GETDATE() AS LASTCHANGED -- * datetime
    ,GETDATE() AS CREATED -- * datetime
    ,NULL AS MODIFIER -- int
    ,NULL AS CREATOR -- int
    ,NULL AS ELOZOTANEVIREKORDID -- int
  FROM T_ERTEKELESMOD d 
  WHERE d.TOROLT = 'F' AND d.C_ALTANEVID = @tanevId 
    AND NOT EXISTS (SELECT 1 FROM T_TANARIATLAGSULY x WHERE x.C_ERTEKELESMODID = d.ID AND x.C_TANEVID = d.C_ALTANEVID AND x.TOROLT = 'F')

  UPDATE T_OKTATASINEVELESIFELADAT SET C_FELADATKATEGORIAID = 7553 WHERE C_FELADATKATEGORIAID IS NULL
  --UPDATE T_OKTATASINEVELESIFELADAT SET C_FELADATKATEGORIAID = 7555 WHERE ID IN (1159, 7664)
  ALTER TABLE T_OKTATASINEVELESIFELADAT ALTER COLUMN C_FELADATKATEGORIAID INT NOT NULL
  CREATE NONCLUSTERED INDEX [NCI_OktatasiNevelesiFeladat_AlintezmenyId_AltanevId_FeladatKategoriaId] ON [dbo].[T_OKTATASINEVELESIFELADAT]([C_ALINTEZMENYID] ASC, [C_ALTANEVID] ASC, [C_FELADATKATEGORIAID] ASC);
  
  UPDATE T_CSOPORTTIPUS SET C_ISTANORAICELU = 'T' WHERE ID = 1034 /* Iskolai csoport (tanórai célú) */ AND C_ALINTEZMENYID = @intezmenyId
  UPDATE csoportTipus SET C_ORAPERC = 45 FROM T_CSOPORTTIPUS csoportTipus WHERE csoportTipus.C_ORAPERC IS NULL AND csoportTipus.TOROLT = 'F' AND C_ALINTEZMENYID = @intezmenyId
  UPDATE csoportTipus SET C_ORAPERC = 1 FROM T_CSOPORTTIPUS csoportTipus WHERE csoportTipus.C_ORAPERC IS NULL AND csoportTipus.ID = 1031 AND csoportTipus.TOROLT = 'F' AND C_ALINTEZMENYID = @intezmenyId
  UPDATE csoportTipus SET C_ORAPERC = 20 FROM T_CSOPORTTIPUS csoportTipus WHERE csoportTipus.C_ORAPERC IS NULL AND csoportTipus.ID = 1032 AND csoportTipus.TOROLT = 'F' AND C_ALINTEZMENYID = @intezmenyId
  UPDATE csoportTipus SET C_ORAPERC = 30 FROM T_CSOPORTTIPUS csoportTipus WHERE csoportTipus.C_ORAPERC IS NULL AND csoportTipus.ID IN (1067,6757,6759,6761) AND csoportTipus.TOROLT = 'F' AND C_ALINTEZMENYID = @intezmenyId
  UPDATE csoportTipus SET C_ORAPERC = 60 FROM T_CSOPORTTIPUS csoportTipus WHERE csoportTipus.C_ORAPERC IS NULL AND csoportTipus.ID IN (1035,1036,1046,1052,1053,1055,1056,1058,1059,1073,7684,7685,7686,7725) AND csoportTipus.TOROLT = 'F' AND C_ALINTEZMENYID = @intezmenyId
  PRINT 'Szótárelemek létrehozása sikeres!';
  --------------------------- SZÓTÁRELEMEK LÉTREHOZÁSA VÉGE ---------------------------
  
  --------------------------- INTÉZMÉNYI ADATOK LÉTREHOZÁSA ---------------------------
  INSERT INTO [dbo].[T_INTEZMENYADATOK] (
     [C_IGAZGATONEVE]
    ,[C_NEV]
    ,[C_OMKOD]
    ,[C_TELEFONSZAM]
    ,[C_EMAILCIM]
    ,[C_IRANYITOSZAM]
    ,[C_VAROS]
    ,[C_KOZTERULETNEV]
    ,[C_KOZTERULETJELLEGENEV]
    ,[C_HAZSZAM]
    ,[C_EMELET]
    ,[C_AJTO]
    ,[C_ROVIDNEV]
    ,[C_KRETATIPUS]
    ,[C_TANEVID]
    ,[C_INTEZMENYID]
    ,[TOROLT]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR]
    ,[C_SNINEVELESIFORMATIPUSID]
    ,[C_ISDKTAKTIV]
    ,[C_DKTTANARURL]
    ,[C_DKTTANULOURL]
  ) VALUES (
     @intezmenyIgazgato
    ,@intezmenyNeve
    ,@intezmenyOMKod
    ,'Nincs adat'
    ,@intezmenyEmail
    ,@intezmenyIranyitoSzam
    ,@intezmenyVaros
    ,@intezmenyKozteruletNev
    ,@intezmenyKozteruletJellegNev
    ,@intezmenyHazszam
    ,@intezmenyEmelet
    ,@intezmenyAjto
    ,@intezmenyAzonosito
    ,CASE @teljesKreta
      WHEN 1 THEN 3025 -- Teljes KRÉTA
      ELSE 3024 -- Csak adatszolgáltatás
     END
    ,@tanevId
    ,@intezmenyId
    ,'F'
    ,0
    ,getdate()
    ,getdate()
    ,null
    ,null
    ,7723
    ,'T'
    ,'https://dkttanar.e-kreta.hu/sso'
    ,'https://dkttanulo.e-kreta.hu/sso'
  )
  
  PRINT 'Intézményi adatok létrehozása sikeres!';
  DECLARE @intezmenyAdatokID int = SCOPE_IDENTITY();
  --------------------------- INTÉZMÉNYI ADATOK LÉTREHOZÁSA VÉGE ---------------------------
  --------------------------- INTÉZMÉNYI ADATSZOLGÁLTATÁS LÉTREHOZÁSA ---------------------------
  INSERT INTO [dbo].[T_INTEZMENYADATSZOLGALTATAS] (
     [C_INTEZMENYID]
    ,[C_TANEVID]
    ,[TOROLT]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR]
  ) VALUES (
     @intezmenyId
    ,@tanevId
    ,'F'
    ,0
    ,getdate()
    ,getdate()
    ,null
    ,null
  )
  --------------------------- INTÉZMÉNYI ADATSZOLGÁLTATÁS LÉTREHOZÁSA VÉGE ---------------------------
  --------------------------- TANÉV RENDJE LÉTREHOZÁSA --------------------------------
  EXEC [dev].[uspCreateTanevRendje] @intezmenyId, @tanevId
  PRINT 'Tanév rendje létrehozása sikeres!';
  --------------------------- TANÉV RENDJE LÉTREHOZÁSA VÉGE ---------------------------
  --------------------------- CSENGETÉSI REND LÉTREHOZÁSA -----------------------------
  DECLARE @csengetesiRendId int
  INSERT [dbo].[T_CSENGETESIREND] ([C_AKTIV], [C_NEV], [C_MUKODESIHELYID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [CREATED], [CREATOR]) VALUES 
    (N'T', N'Csengetési rend', NULL, @intezmenyId, @tanevId, N'F', 4, GETDATE(), 2)
  SET @csengetesiRendId = SCOPE_IDENTITY()
  INSERT [dbo].[T_CSENGETESIRENDORA] ([C_KEZDETE], [C_ORASZAM], [C_VEGE], [C_CSENGETESIRENDID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [CREATED], [CREATOR]) VALUES 
    ('19000101 08:00:00.000', 1, '19000101 08:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 09:00:00.000', 2, '19000101 09:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 10:00:00.000', 3, '19000101 10:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 11:00:00.000', 4, '19000101 11:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 12:00:00.000', 5, '19000101 12:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 13:00:00.000', 6, '19000101 13:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 2, GETDATE(), 2),
    ('19000101 14:00:00.000', 7, '19000101 14:45:00.000', @csengetesiRendId, @intezmenyId, @tanevId, 'F', 1, GETDATE(), 2)
  PRINT 'Csengetési rend létrehozása sikeres!';
  --------------------------- CSENGETÉSI REND LÉTREHOZÁSA VÉGE ------------------------
 
  --------------------------- ALAP FELHASZNÁLÓK LÉTREHOZÁSA ---------------------------

  -- Szuper admin létrehozása
  DECLARE @SUPERADMINID INT
  INSERT INTO [dbo].[T_FELHASZNALO] (
     [C_NEME]
    ,[C_SZULETESIDATUM]
    ,[C_SZULETESINEV]
    ,[C_ANYJANEVE]
    ,[C_SZULETESIHELY]
    ,[C_TAJSZAM]
    ,[C_ALLAMPOLGARSAGA]
    ,[C_KERESESINEV]
    ,[C_SZULETESIORSZAG]
    ,[C_SZULETESINEVSORREND]
    ,[C_ANYJANEVESORREND]
    ,[C_ALAPERTELMEZETTLCID]
    ,[C_LATASSERULTWEBHASZNALATA]
    ,[C_SMSSZAM]
    ,[C_SMSSZINKRONIZALT]
    ,[C_KELLADSZINKRONIZALAS]
    ,[C_DMSTARTTIME]
    ,[C_NYOMTATASINEV]
    ,[C_UTONEV]
    ,[C_VEZETEKNEV]
    ,[C_ADOAZONOSITOJEL]
    ,[C_ELOTAG]
    ,[C_ANYANYELVE]
    ,[C_IGAZOLVANYSZAM]
    ,[C_IGAZOLVANYTIPUSA]
    ,[C_NEVSORREND]
    ,[C_NYILVANTARTASISZAM]
    ,[C_NYILVANTARTASKEZDETE]
    ,[C_OKTATASIAZONOSITO]
    ,[C_OMKOD]
    ,[C_INTEZMENYID]
    ,[C_TANEVID]
    ,[C_EGYEDIAZONOSITO]
    ,[C_IDPEGYEDIAZONOSITO]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR]
  ) VALUES (
     4
    ,'1980-01-01'
    ,'Kréta Adminisztrátor'
    ,'Kréta Adminisztrátor'
    ,NULL
    ,NULL
    ,217
    ,'admin'
    ,765
    ,'T'
    ,'T'
    ,1038
    ,'F'
    ,0
    ,'F'
    ,'T'
    ,NULL
    ,'Kréta Adminisztrátor'
    ,'Adminisztrátor'
    ,'Kréta'
    ,NULL
    ,NULL
    ,509
    ,NULL
    ,NULL
    ,'T'
    ,NULL
    ,GETDATE()
    ,'00001'
    ,NULL
    ,@intezmenyId
    ,@tanevId
    ,CAST(NEWID() AS NVARCHAR(36))
    ,NEWID()
    ,0
    ,GETDATE()
    ,GETDATE()
    ,NULL
    ,1
  )
  SET @SUPERADMINID = SCOPE_IDENTITY()
  PRINT 'Szuper admin létrehozása sikeres!';

  -- Szuperadmin e-mail címe
  INSERT INTO [dbo].[T_EMAIL] (
    [C_EMAILTIPUSA], [C_EMAILCIM], [C_ALAPERTELMEZETT], [C_FELHASZNALOID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [CREATED], [CREATOR]
  ) VALUES
    (1025, @intezmenyEmail, 'T', @SUPERADMINID, @intezmenyId, @tanevId, 'F', 0, GETDATE(), 1)

  SET @so = CAST((SELECT RandomNumber FROM dev.vGetRand) AS nvarchar(64))
  SET @jelszoHash = dev.fnConvertBase64(HASHBYTES('SHA1', CONVERT(VARBINARY(MAX), CONVERT(NVARCHAR(MAX), @adminJelszo + @so))))

  IF @kovetkezoTanev = 0 BEGIN
      -- Szuperadmin belépés
      INSERT INTO [dbo].[T_FELHASZNALOBELEPES] (
         [C_BEJELENTKEZESINEV]
        ,[C_KOTELEZOVALTOZTATNI]
        ,[C_MEGHIUSULTBELEPESEK]
        ,[C_UTOLSOBELEPES]
        ,[C_JELSZO]
        ,[C_JELSZOVALTOZTATASIDEJE]
        ,[C_SO]
        ,[c_felhasznaloId]
        ,[C_GONDVISELOID]
        ,[C_INTEZMENYID]
        ,[C_TANEVID]
        ,[SERIAL]
        ,[LASTCHANGED]
        ,[CREATED]
        ,[MODIFIER]
        ,[CREATOR]        
      ) VALUES (
         'admin'
        ,'F'
        ,0
        ,GETDATE()
        ,@jelszoHash
        ,GETDATE()
        ,@so
        ,@SUPERADMINID
        ,null
        ,@intezmenyId
        ,@tanevId
        ,1
        ,GETDATE()
        ,GETDATE()
        ,null
        ,1        
      )
    PRINT 'Szuper admin belépés létrehozása sikeres!';
  END
  DECLARE @ADMINSZEREPKORID INT = NULL
  INSERT INTO [dbo].T_SZEREPKOR (
     [C_SZEREPKORTIPUS]
    ,[C_INTEZMENYID]
    ,[C_TANEVID]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR]
  ) SELECT 
     ID
    ,C_ALINTEZMENYID
    ,C_ALTANEVID
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,MODIFIER
    ,CREATOR
  FROM T_SZEREPKORTIPUS 
  WHERE C_ALINTEZMENYID = @intezmenyId 
    AND C_ALTANEVID = @tanevId

  SELECT @ADMINSZEREPKORID = ID 
  FROM dbo.T_SZEREPKOR 
  WHERE C_SZEREPKORTIPUS = 1758 AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
 --------------------------- ALAP FELHASZNÁLÓK LÉTREHOZÁSA VÉGE ---------------------------
--------------------------- SÉMA LÉTREHOZÁSA ----------------------------------

  IF(@vanmasikTanev = 0)BEGIN
    DECLARE @intezmenyIdString nvarchar(30) = CAST(@intezmenyId AS nvarchar(30))
    EXEC dev.uspCreateSchemaAndOthers
       @pDbJelszo = @dbJelszo
      ,@pIntezmenyIds = @intezmenyIdString
  END

-- Rendszer értesítések adminnak alapadatok
  INSERT INTO dbo.T_RENDSZERERTESITESEK(
    C_BEALLITASOKELLENORZESE,
    C_FRISSITESIDEJE,
    C_INTEZMENYHIANYOSADATOK,
    C_KELLFRISSITES,
    C_ORARENDTANARUTKOZES,
    C_ORARENDTANULOUTKOZESEK,
    C_ORARENDTEREMUTKOZES,
    C_TANAROKHIANYOSOKTATASIAZONOS,
    C_TANTARGYFELOSZTASOSZTALYOKNI,
    C_TANTARGYFELOSZTASTANARNINCSE,
    C_TANTARGYFELOSZTASTANTARGYNIN,
    C_TANULOHIANYOSOKTATASIAZONOSI,
    C_TANULOKOSZTALYBASOROLASA,
    C_INTEZMENYID,
    C_TANEVID,
    TOROLT,
    SERIAL,
    LASTCHANGED,
    CREATED,
    MODIFIER,
    CREATOR
  ) VALUES (
    'F', -- C_BEALLITASOKELLENORZESE - char
    GETDATE(), -- C_FRISSITESIDEJE - datetime
    'F', -- C_INTEZMENYHIANYOSADATOK - char
    'F', -- C_KELLFRISSITES - char
    0, -- C_ORARENDTANARUTKOZES - int
    0, -- C_ORARENDTANULOUTKOZESEK - int
    0, -- C_ORARENDTEREMUTKOZES - int
    0, -- C_TANAROKHIANYOSOKTATASIAZONOS - int
    0, -- C_TANTARGYFELOSZTASOSZTALYOKNI - int
    0, -- C_TANTARGYFELOSZTASTANARNINCSE - int
    0, -- C_TANTARGYFELOSZTASTANTARGYNIN - int
    0, -- C_TANULOHIANYOSOKTATASIAZONOSI - int
    0, -- C_TANULOKOSZTALYBASOROLASA - int
    @intezmenyId, --  C_INTEZMENYID,
    @tanevId, --C_TANEVID,
    'F', -- TOROLT - char
    0, -- SERIAL - int
    GETDATE(), -- LASTCHANGED - datetime
    GETDATE(), -- CREATED - datetime
    0, -- MODIFIER - int
    0 -- CREATOR - int
  )
-- JOGOSULTSÁG
  DECLARE @RENDSZERGAZDAJOGID INT = NULL
  SELECT TOP 1 @RENDSZERGAZDAJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Rendszergazda' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@RENDSZERGAZDAJOGID IS NULL) BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG  (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID], [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES (
      N'Rendszergazda', -- C_JOG - nvarchar
      1758, -- Adminisztrátor
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @RENDSZERGAZDAJOGID = SCOPE_IDENTITY()
  END
  DECLARE @OSZTALYFONOKJOGID INT = NULL
  SELECT TOP 1 @OSZTALYFONOKJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Osztalyfonok' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@OSZTALYFONOKJOGID IS NULL)BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG(
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES(
      N'Osztalyfonok', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @OSZTALYFONOKJOGID = SCOPE_IDENTITY()
  END
  DECLARE @EVFOLYAMFELELOSJOGID INT = NULL
  SELECT TOP 1 @EVFOLYAMFELELOSJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Evfolyamfelelos' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@EVFOLYAMFELELOSJOGID IS NULL)BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG  (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES (
      N'Evfolyamfelelos', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @EVFOLYAMFELELOSJOGID = SCOPE_IDENTITY()
  END
  DECLARE @CSOPORTVEZETOJOGID INT = NULL
  SELECT TOP 1 @CSOPORTVEZETOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'CsoportVezeto' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@CSOPORTVEZETOJOGID IS NULL)BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG (    
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES(
      N'CsoportVezeto', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @CSOPORTVEZETOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @SZUPEROSZTALYFONOKJOGID INT = NULL
  SELECT TOP 1 @SZUPEROSZTALYFONOKJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'SzuperOsztalyfonok' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@SZUPEROSZTALYFONOKJOGID IS NULL)  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG  (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES   (
      N'SzuperOsztalyfonok', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @SZUPEROSZTALYFONOKJOGID = SCOPE_IDENTITY()
  END
  DECLARE @TANARJOGID INT = NULL
  SELECT TOP 1 @TANARJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Tanar' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@TANARJOGID IS NULL) BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG(
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    ) VALUES (
      N'Tanar', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @TANARJOGID = SCOPE_IDENTITY()
  END
  DECLARE @GONDVISELOJOGID INT = NULL
  SELECT TOP 1 @GONDVISELOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Gondviselo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@GONDVISELOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )  VALUES (
      N'Gondviselo', -- C_JOG - nvarchar
      1761, -- ELLENŐRZŐ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @GONDVISELOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @TANULOJOGID INT = NULL
  SELECT TOP 1 @TANULOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Tanulo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@TANULOJOGID IS NULL) BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    ) VALUES (
      N'Tanulo', -- C_JOG - nvarchar
      1761, -- ELLENŐRZŐ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @TANULOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ADMINISZTRATORJOGID INT = NULL
  SELECT TOP 1 @ADMINISZTRATORJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Adminisztrator' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ADMINISZTRATORJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    ) VALUES (
      N'Adminisztrator', -- C_JOG - nvarchar
      1758, -- ADMIN
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ADMINISZTRATORJOGID = SCOPE_IDENTITY()
  END
  DECLARE @NAPLOJOGID INT = NULL
  SELECT TOP 1 @NAPLOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Naplo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@NAPLOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Naplo', -- C_JOG - nvarchar
      1760, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @NAPLOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ELLENORZOJOGID INT = NULL
  SELECT TOP 1 @ELLENORZOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Ellenorzo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ELLENORZOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Ellenorzo', -- C_JOG - nvarchar
      1761, -- ELLENŐRZŐ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ELLENORZOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @SZUPERADMINJOGID INT = NULL
  SELECT TOP 1 @SZUPERADMINJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Szuperadmin' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@SZUPERADMINJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Szuperadmin', -- C_JOG - nvarchar
      1758, -- ADMIN
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @SZUPERADMINJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ALAIROJOGID INT = NULL
  SELECT TOP 1 @ALAIROJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Alairo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ALAIROJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Alairo', -- C_JOG - nvarchar
      7373, -- Alairo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ALAIROJOGID = SCOPE_IDENTITY()
  END
  DECLARE @EUGYINTEZOJOGID INT = NULL
  SELECT TOP 1 @EUGYINTEZOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'eUgyintezo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@EUGYINTEZOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'eUgyintezo', -- C_JOG - nvarchar
      7374, -- eUgyintezo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @EUGYINTEZOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @PENZTAROSJOGID INT = NULL
  SELECT TOP 1 @PENZTAROSJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Penztaros' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@PENZTAROSJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Penztaros', -- C_JOG - nvarchar
      7372, -- Penztaros
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @PENZTAROSJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ETKEZESIADMINJOGID INT = NULL
  SELECT TOP 1 @ETKEZESIADMINJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'EtkezesiAdmin' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ETKEZESIADMINJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'EtkezesiAdmin', -- C_JOG - nvarchar
      7703, -- EtkezesiAdmin
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ETKEZESIADMINJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ETKEZESIELLENORZOJOGID INT = NULL
  SELECT TOP 1 @ETKEZESIELLENORZOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'EtkezesiEllenorzo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ETKEZESIELLENORZOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'EtkezesiEllenorzo', -- C_JOG - nvarchar
      7704, -- EtkezesiEllenorzo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ETKEZESIELLENORZOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @TEREMBERLETJELENLETELLENORZOJOGID INT = NULL
  SELECT TOP 1 @TEREMBERLETJELENLETELLENORZOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'TeremberletJelenletEllenorzo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@TEREMBERLETJELENLETELLENORZOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'TeremberletJelenletEllenorzo', -- C_JOG - nvarchar
      7705, -- TeremberletJelenletEllenorzo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @TEREMBERLETJELENLETELLENORZOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ALKALMAZOTTJOGID INT = NULL
  SELECT TOP 1 @ALKALMAZOTTJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Alkalmazott' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ALKALMAZOTTJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Alkalmazott', -- C_JOG - nvarchar
      7781, -- TeremberletJelenletEllenorzo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ALKALMAZOTTJOGID = SCOPE_IDENTITY()
  END
  DECLARE @FOKUSZMONITORINGJOGID INT = NULL
  SELECT TOP 1 @FOKUSZMONITORINGJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'FokuszMonitoring' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FOKUSZMONITORINGJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'FokuszMonitoring', -- C_JOG - nvarchar
      7702, -- FokuszMonitoring
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @FOKUSZMONITORINGJOGID = SCOPE_IDENTITY()
  END
  DECLARE @BelepokartyaAdminID INT = NULL
  SELECT TOP 1 @BelepokartyaAdminID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'BelepokartyaAdmin' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@BelepokartyaAdminID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'BelepokartyaAdmin', -- C_JOG - nvarchar
      8753, -- BelepokartyaAdmin
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @BelepokartyaAdminID = SCOPE_IDENTITY()
  END
  DECLARE @LELTARJOGID INT = NULL
  SELECT TOP 1 @LELTARJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'LELTAR_CONCERNED' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@LELTARJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'LELTAR_CONCERNED', -- C_JOG - nvarchar
      8755, -- LELTAR
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @LELTARJOGID = SCOPE_IDENTITY()
  END

  DECLARE @KonyvatrosID INT = NULL
  SELECT TOP 1 @KonyvatrosID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Konyvatros' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@KonyvatrosID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Konyvatros', -- C_JOG - nvarchar
      8824, -- Konyvtaros
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @KonyvatrosID = SCOPE_IDENTITY()
  END

  DECLARE @FELTAREsetKezeloJogId INT = NULL
  SELECT TOP 1 @FELTAREsetKezeloJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_EsetKezelo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTAREsetKezeloJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_EsetKezelo',8828,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTAREsetKezeloJogId = SCOPE_IDENTITY()
  END

  DECLARE @FELTAREszkozMenedzserJogId INT = NULL
  SELECT TOP 1 @FELTAREszkozMenedzserJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_EszkozMenedzser' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTAREszkozMenedzserJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_EszkozMenedzser',8829,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTAREszkozMenedzserJogId = SCOPE_IDENTITY()
  END

  DECLARE @FELTARSzerzodesMenedzserJogId INT = NULL
  SELECT TOP 1 @FELTARSzerzodesMenedzserJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_SzerzodesMenedzser' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTARSzerzodesMenedzserJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_SzerzodesMenedzser',9061,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTARSzerzodesMenedzserJogId = SCOPE_IDENTITY()
  END

  DECLARE @FELTAREsetJovahagyoJogId INT = NULL
  SELECT TOP 1 @FELTAREsetJovahagyoJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_EsetJovahagyo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTAREsetJovahagyoJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_EsetJovahagyo',9062,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTAREsetJovahagyoJogId = SCOPE_IDENTITY()
  END

  DECLARE @FELTAREsetKozremukodoJogId INT = NULL
  SELECT TOP 1 @FELTAREsetKozremukodoJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_EsetKozremukodo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTAREsetKozremukodoJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_EsetKozremukodo',9063,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTAREsetKozremukodoJogId = SCOPE_IDENTITY()
  END

  DECLARE @FELTARMunkavegzoJogId INT = NULL
  SELECT TOP 1 @FELTARMunkavegzoJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'FELTAR_Munkavegzo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@FELTARMunkavegzoJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'FELTAR_Munkavegzo',9064,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @FELTARMunkavegzoJogId = SCOPE_IDENTITY()
  END

  DECLARE @KerdoivKitoltoKerdoivKezeloJogId INT = NULL
  SELECT TOP 1 @KerdoivKitoltoKerdoivKezeloJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'KerdoivKitolto_KerdoivKezelo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@KerdoivKitoltoKerdoivKezeloJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'KerdoivKitolto_KerdoivKezelo',8961,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @KerdoivKitoltoKerdoivKezeloJogId = SCOPE_IDENTITY()
  END

  DECLARE @DualisAdminJogId INT = NULL
  SELECT TOP 1 @DualisAdminJogId = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = N'Dualis_Admin' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@DualisAdminJogId IS NULL)
  BEGIN
  	INSERT INTO dbo.T_JOGOSULTSAG (C_JOG,C_SZEREPKORTIPUS,[C_INTEZMENYID],[C_TANEVID],TOROLT,SERIAL,CREATED,CREATOR)
  	  VALUES (N'Dualis_Admin',9001,@intezmenyId , @tanevId,'F',0,GETDATE(),0)
  	SET @DualisAdminJogId = SCOPE_IDENTITY()
  END

  DECLARE @PENZUGYIADMINJOGID INT = NULL
  SELECT TOP 1 @PENZUGYIADMINJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'PenzugyiAdmin' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@PENZUGYIADMINJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'PenzugyiAdmin', -- C_JOG - nvarchar
      7371, -- NAPLÓ
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @PENZUGYIADMINJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ISKOLAEGESZSEGUGYIKOORDINATORJOGID INT = NULL
  SELECT TOP 1 @ISKOLAEGESZSEGUGYIKOORDINATORJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'IskolaEgeszsegugyiKoordinator' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ISKOLAEGESZSEGUGYIKOORDINATORJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'IskolaEgeszsegugyiKoordinator', -- C_JOG - nvarchar
      7789, -- IskolaEgeszsegugyiKoordinator
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ISKOLAEGESZSEGUGYIKOORDINATORJOGID = SCOPE_IDENTITY()
  END
  DECLARE @VEDONOJOGID INT = NULL
  SELECT TOP 1 @VEDONOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Vedono' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@VEDONOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Vedono', -- C_JOG - nvarchar
      7790, -- Vedono
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @VEDONOJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ISKOLAORVOSJOGID INT = NULL
  SELECT TOP 1 @ISKOLAORVOSJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'Iskolaorvos' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ISKOLAORVOSJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'Iskolaorvos', -- C_JOG - nvarchar
      7791, -- Iskolaorvos
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ISKOLAORVOSJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ISKOLAEGESZSEGUGYIASSZISZTENSJOGID INT = NULL
  SELECT TOP 1 @ISKOLAEGESZSEGUGYIASSZISZTENSJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'IskolaEgeszsegugyiAsszisztens' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ISKOLAEGESZSEGUGYIASSZISZTENSJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'IskolaEgeszsegugyiAsszisztens', -- C_JOG - nvarchar
      7792, -- IskolaEgeszsegugyiAsszisztens
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ISKOLAEGESZSEGUGYIASSZISZTENSJOGID = SCOPE_IDENTITY()
  END
  DECLARE @ISKOLAEGESZSEGUGYILEKERDEZOJOGID INT = NULL
  SELECT TOP 1 @ISKOLAEGESZSEGUGYILEKERDEZOJOGID = ID FROM dbo.T_JOGOSULTSAG WHERE C_JOG = 'IskolaEgeszsegugyiLekerdezo' AND C_INTEZMENYID = @intezmenyId AND C_TANEVID = @tanevId
  IF(@ISKOLAEGESZSEGUGYILEKERDEZOJOGID IS NULL)
  BEGIN
    INSERT INTO dbo.T_JOGOSULTSAG
    (
      C_JOG,  C_SZEREPKORTIPUS,[C_INTEZMENYID] , [C_TANEVID],  TOROLT,  SERIAL,  CREATED,  CREATOR 
    )
    VALUES
    (
      N'IskolaEgeszsegugyiLekerdezo', -- C_JOG - nvarchar
      7793, -- IskolaEgeszsegugyiLekerdezo
      @intezmenyId , @tanevId,
      'F', -- TOROLT - char
      0, -- SERIAL - int
      GETDATE(), -- CREATED - datetime
      0 -- CREATOR - int
    )
    SET @ISKOLAEGESZSEGUGYILEKERDEZOJOGID = SCOPE_IDENTITY()
  END
  -- Jogosultság
  INSERT INTO T_FELHASZNALO_SZEREPKOR (C_SZEREPKORID, C_FELHASZNALOID)
  VALUES (@ADMINSZEREPKORID, @SUPERADMINID)   -- admin
  INSERT INTO T_JOGOSULTSAG_FELHASZNALO (C_JOGOSULTSAGID, C_FELHASZNALOID)
  VALUES (@SZUPERADMINJOGID, @SUPERADMINID)  -- szuperadmin
  -- Működési hely
  -- Feladatellátási hely
  INSERT INTO [dbo].[T_MUKODESIHELY]
     ([C_NEV]
     ,[C_EMAILCIM]
     ,[C_FAX]
     ,[C_TELEFONSZAM]
     ,[C_IRANYITOSZAM]
     ,[C_VAROS]
     ,[C_KOZTERULETNEV]
     ,[C_KOZTERULETJELLEGENEV]
     ,[C_HAZSZAM]
     ,[C_EMELET]
     ,[C_AJTO]
     ,[C_VEZETONEVE]
     ,[C_TAGINTEZMENY]
     ,[C_TAGINTEZMENYIKOD]
     ,[C_INTEZMENYADATOKID]
     ,[C_INTEZMENYID]
     ,[C_TANEVID]
     ,[TOROLT]
     ,[SERIAL]
     ,[LASTCHANGED]
     ,[CREATED]
     ,[MODIFIER]
     ,[CREATOR])
  VALUES
     ('Működési hely'
     ,@intezmenyEmail
     ,NULL
     ,NULL
     ,@intezmenyIranyitoSzam
     ,@intezmenyVaros
     ,@intezmenyKozteruletNev
     ,@intezmenyKozteruletJellegNev
     ,@intezmenyHazszam
     ,@intezmenyEmelet
     ,@intezmenyAjto
     ,@intezmenyIgazgato
     ,CASE WHEN @intezmenyTagkod IS NOT NULL THEN 'T' ELSE 'F' END
     ,@intezmenyTagkod
     ,@intezmenyAdatokID
     ,@intezmenyId
     ,@tanevId
     ,'F'
     ,0
     ,GETDATE()
     ,GETDATE()
     ,NULL
     ,1)
  DECLARE @MukodesiHelyId int = SCOPE_IDENTITY()  
  -- Feladatellátási hely
  INSERT INTO [dbo].[T_FELADATELLATASIHELY]
    ([C_OKTATASINEVELESIFELADATTIPUS]
    ,[C_MUKODESIHELYID]
    ,[C_INTEZMENYID]
    ,[C_TANEVID]
    ,[TOROLT]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR])
  VALUES
    (1156
    ,@MukodesiHelyId  
    ,@intezmenyId
    ,@tanevId
    ,'F'
    ,0
    ,GETDATE()
    ,GETDATE()
    ,NULL
    ,1)
  -- Tanterv
  INSERT INTO [dbo].[T_TANTERV]
      ([C_CSOPORTTIPUSA]
      ,[C_EVFOLYAMTOL]
      ,[C_EVFOLYAMIG]
      ,[C_KERETTANTERVREEPULO]
      ,[C_NEV]
      ,[C_INTEZMENYID]
      ,[C_TANEVID]
      ,[TOROLT]
      ,[SERIAL]
      ,[LASTCHANGED]
      ,[CREATED]
      ,[MODIFIER]
      ,[CREATOR]
      ,[C_VEDETT])
  VALUES
      (1034
      ,1303
      ,1310
      ,'T'
      ,'Kerettanterv'
      ,@intezmenyId
        ,@tanevId
      ,'F'
      ,0
      ,GETDATE()
      ,GETDATE()
      ,NULL
      ,1
      ,'T')
--Default Tantárgy
  INSERT INTO [dbo].[T_TANTARGY]
    ([C_GYAKORLATI]
    ,[C_NEV]
    ,[C_ROVIDNEV]
    ,[C_TARGYKATEGORIA]
    ,[C_TANORANKIVULI]
    ,[C_IMPORTALT]
    ,[C_FOTARGYE]
    ,[C_INTEZMENYID]
    ,[C_TANEVID]
    ,[TOROLT]
    ,[SERIAL]
    ,[LASTCHANGED]
    ,[CREATED]
    ,[MODIFIER]
    ,[CREATOR])
  VALUES
    ('F'
    ,'Tanórán kívüli foglalkozás'
    ,'tanórán kívüli'
    ,1197
    ,'T'
    ,'F'
    ,'T'
    ,@intezmenyId
      ,@tanevId
    ,'F'
    ,0
    ,GETDATE()
    ,GETDATE()
    ,NULL
    ,1)
  PRINT 'Tanterv létrehozása sikeres!';
  -- A-B hét, ha szükséges
  IF (@kellABHet = 1)BEGIN
    INSERT INTO [dbo].[T_DICTIONARYITEMBASE]
           ([C_VALUE], [C_NAME], [C_VISIBLE], [C_TYPE], [C_PROTECTED], [C_DICTIONARYTYPEID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [CREATED], [CREATOR])
       VALUES
           (2, 'A hét', 'T', 'HetiRendTipus', 'F', 49, @intezmenyId, @tanevId, 'F', 0, GETDATE(), 1)
    INSERT INTO [dbo].[T_HETIRENDTIPUS] (ID, C_ALINTEZMENYID, C_ALTANEVID)
      VALUES (SCOPE_IDENTITY(), @intezmenyId, @tanevId)
    INSERT INTO [dbo].[T_DICTIONARYITEMBASE]
           ([C_VALUE], [C_NAME], [C_VISIBLE], [C_TYPE], [C_PROTECTED], [C_DICTIONARYTYPEID], [C_INTEZMENYID], [C_TANEVID], [TOROLT], [SERIAL], [CREATED], [CREATOR])
       VALUES
           (3, 'B hét', 'T', 'HetiRendTipus', 'F', 49, @intezmenyId, @tanevId, 'F', 0, GETDATE(), 1)
    INSERT INTO [dbo].[T_HETIRENDTIPUS] (ID, C_ALINTEZMENYID, C_ALTANEVID)
      VALUES (SCOPE_IDENTITY(), @intezmenyId, @tanevId)
    PRINT 'A-B hét hetirend létrehozása sikeres!';
  END
  --------------------------- NAPTÁRI HÉT LÉTREHOZÁSA --------------------------------
  DECLARE @sql nvarchar(max)
  DECLARE @schemaName nvarchar(100) = 'KR_' +@intezmenyAzonosito+ '_Schema'

  SET @sql ='EXEC  ['+@schemaName+'].[sp_GenerateNaptariHetek] @intezmenyId = @intezmenyId, @tanevId = @tanevId '
  EXEC sp_executesql @sql, N'@intezmenyId INT, @tanevId INT', @intezmenyId, @tanevId
  PRINT 'Naptári hetek létrehozása sikeres!';
  --------------------------- NAPTÁRI HÉT LÉTREHOZÁSA VÉGE --------------------------------
  --------------------------- NAPTÁRI NAP LÉTREHOZÁSA --------------------------------
  SET @sql ='EXEC  ['+@schemaName+'].[sp_GenerateNaptariNapok] @intezmenyId = @intezmenyId, @tanevId = @tanevId '
  EXEC sp_executesql @sql, N'@intezmenyId INT, @tanevId INT', @intezmenyId, @tanevId
  PRINT 'Naptári napok létrehozása sikeres!'
  --------------------------- NAPTÁRI NAP LÉTREHOZÁSA VÉGE --------------------------------

  EXEC dev.CreateSystemSettingsDefaultData @intezmenyId, @tanevId


  --------------------------- T_KEPESITES FELTÖLTÉSE --------------------------------------
  INSERT INTO T_KEPESITES (
     C_KEPESITESTIPUSID
    ,C_INTEZMENYID
    ,C_TANEVID
    ,TOROLT
    ,SERIAL
    ,LASTCHANGED
    ,CREATED
    ,MODIFIER
    ,CREATOR
    ,ELOZOTANEVIREKORDID
  ) SELECT 
     sz.ID AS C_KEPESITESTIPUSID     -- C_KEPESITESTIPUSID - int
    ,sz.C_ALINTEZMENYID   AS C_INTEZMENYID           -- C_INTEZMENYID - int
    ,sz.C_ALTANEVID   AS C_TANEVID               -- C_TANEVID - int
    ,'F'  AS TOROLT                  -- TOROLT - char(1)
    ,0   AS SERIAL                  -- SERIAL - int
    ,GETDATE() AS LASTCHANGED       -- LASTCHANGED - datetime
    ,GETDATE() AS CREATED           -- CREATED - datetime
    ,sz.MODIFIER AS MODIFIER               -- MODIFIER - int
    ,sz.CREATOR AS CREATOR                -- CREATOR - int
    ,NULL AS ELOZOTANEVIREKORDID    -- ELOZOTANEVIREKORDID - int
  FROM T_SZAKTIPUS sz
  WHERE sz.C_ALINTEZMENYID = @intezmenyId
    AND sz.C_ALTANEVID = @tanevId
    AND sz.TOROLT = 'F'
  --------------------------- T_KEPESITES FELTÖLTÉSE VÉGE ---------------------------------
  --Oktatási-nevelési feladatok és ajánlott évfolyamok
  INSERT INTO T_EVFOLYAMTIPUS_OKTATASINEVELE (C_EVFOLYAMTIPUSID, C_OKTATASINEVELESIFELADATID, C_INTEZMENYID, C_TANEVID)
    VALUES
      --ÁLTALÁNOS ISKOLA 1,2,3,4,5,6,7,8
      (1303, 1158, @intezmenyId, @tanevId),
      (1304, 1158, @intezmenyId, @tanevId),
      (1305, 1158, @intezmenyId, @tanevId),
      (1306, 1158, @intezmenyId, @tanevId),
      (1307, 1158, @intezmenyId, @tanevId),
      (1308, 1158, @intezmenyId, @tanevId),
      (1309, 1158, @intezmenyId, @tanevId),
      (1310, 1158, @intezmenyId, @tanevId),
      --Általános iskolai (SNI) 1,2,3,4,5,6,7,8
      (1303, 1178, @intezmenyId, @tanevId),
      (1304, 1178, @intezmenyId, @tanevId),
      (1305, 1178, @intezmenyId, @tanevId),
      (1306, 1178, @intezmenyId, @tanevId),
      (1307, 1178, @intezmenyId, @tanevId),
      (1308, 1178, @intezmenyId, @tanevId),
      (1309, 1178, @intezmenyId, @tanevId),
      (1310, 1178, @intezmenyId, @tanevId),
    
      --Felnőttképzés 1/13, 2/14, 3/15, 1/15, H/I, H/II/1, H/II/2
      (1319, 1176, @intezmenyId, @tanevId),
      (1320, 1176, @intezmenyId, @tanevId),
      (1321, 1176, @intezmenyId, @tanevId),
      (1337, 1176, @intezmenyId, @tanevId),
      --Gimnázium 5, 6, 7, 8, 9, 10, 11, 12, 13
      (1307, 1160, @intezmenyId, @tanevId),
      (1308, 1160, @intezmenyId, @tanevId),
      (1309, 1160, @intezmenyId, @tanevId),
      (1310, 1160, @intezmenyId, @tanevId),
      (1311, 1160, @intezmenyId, @tanevId),
      (1312, 1160, @intezmenyId, @tanevId),
      (1313, 1160, @intezmenyId, @tanevId),
      (1314, 1160, @intezmenyId, @tanevId),
      (1315, 1160, @intezmenyId, @tanevId),
             
      --Kész ségfejlesztő speciális szakiskolai 1/11, 1/12, 1/8, 1/9, 2/10, 2/12, 3/11, 3/13, H/I, H/II/1, H/II/2
      (1317, 1180, @intezmenyId, @tanevId),
      (1326, 1180, @intezmenyId, @tanevId),
      (1324, 1180, @intezmenyId, @tanevId),
      (1316, 1180, @intezmenyId, @tanevId),
      (1323, 1180, @intezmenyId, @tanevId),
      (1318, 1180, @intezmenyId, @tanevId),
      (1325, 1180, @intezmenyId, @tanevId),
      (1322, 1180, @intezmenyId, @tanevId),
    --Konduktív pedagógiai intézmény 1,2,3,4,5,6,7,8,9,10,11,12, 13
      (1303, 1173, @intezmenyId, @tanevId),
      (1304, 1173, @intezmenyId, @tanevId),
      (1305, 1173, @intezmenyId, @tanevId),
      (1306, 1173, @intezmenyId, @tanevId),
      (1307, 1173, @intezmenyId, @tanevId),
      (1308, 1173, @intezmenyId, @tanevId),
      (1309, 1173, @intezmenyId, @tanevId),
      (1310, 1173, @intezmenyId, @tanevId),
      (1311, 1173, @intezmenyId, @tanevId),
      (1312, 1173, @intezmenyId, @tanevId),
      (1313, 1173, @intezmenyId, @tanevId),
      (1314, 1173, @intezmenyId, @tanevId),
      (1315, 1173, @intezmenyId, @tanevId),
      --Óvoda Kis, Középső, Nagy, Óvodai vegyes
      (1297, 1157, @intezmenyId, @tanevId),
      (1298, 1157, @intezmenyId, @tanevId),
      (1299, 1157, @intezmenyId, @tanevId),
      (1300, 1157, @intezmenyId, @tanevId),
      --Óvodai (SNI) Kis, Középső, Nagy, Óvodai vegyes
      (1297, 1177, @intezmenyId, @tanevId),
      (1298, 1177, @intezmenyId, @tanevId),
      (1299, 1177, @intezmenyId, @tanevId),
      (1300, 1177, @intezmenyId, @tanevId),
      --Szakiskola 1/11, 1/12, 1/8, 1/9, 2/10, 2/12, 3/11, 3/13, H/I, H/II/1, H/II/2
      (1317, 1162, @intezmenyId, @tanevId),
      (1326, 1162, @intezmenyId, @tanevId),
      (1324, 1162, @intezmenyId, @tanevId),
      (1316, 1162, @intezmenyId, @tanevId),
      (1323, 1162, @intezmenyId, @tanevId),
      (1318, 1162, @intezmenyId, @tanevId),
      (1325, 1162, @intezmenyId, @tanevId),
      (1322, 1162, @intezmenyId, @tanevId),
      --Szakközépiskola  5, 6, 7, 8, 9, 10, 11, 12, 13
      (1307, 1161, @intezmenyId, @tanevId),
      (1308, 1161, @intezmenyId, @tanevId),
      (1309, 1161, @intezmenyId, @tanevId),
      (1310, 1161, @intezmenyId, @tanevId),
      (1311, 1161, @intezmenyId, @tanevId),
      (1312, 1161, @intezmenyId, @tanevId),
      (1313, 1161, @intezmenyId, @tanevId),
      (1314, 1161, @intezmenyId, @tanevId),
      (1315, 1161, @intezmenyId, @tanevId)
    PRINT N'Oktatási-nevelési feladatok és ajánlott évfolyamok létrehozása sikeres!';
    
  --------------------------- Csoporttípus és foglalkozástípus összerendelés (kapcsolat) --------------------------------
  --Csoporttípus meghatározza a foglalkozástípust
  INSERT INTO T_CSOPORTTIPUS_FOGLALKOZASTIPU (C_FOGLALKOZASTIPUSID, C_CSOPORTTIPUSID, C_CSOPORTBONTOTT, C_INTEZMENYID, C_TANEVID)
    VALUES
    (1338, 1031, null, @intezmenyId, @tanevId),
    (1339, 1034, null, @intezmenyId, @tanevId),
    (1368, 1034, 'T', @intezmenyId, @tanevId),
    (1340, 1035, null, @intezmenyId, @tanevId),
    (1341, 1036, null, @intezmenyId, @tanevId),
    (1343, 1067, null, @intezmenyId, @tanevId),
    (1343, 1068, null, @intezmenyId, @tanevId),
    (1344, 1065, null, @intezmenyId, @tanevId),
    (1345, 1037, null, @intezmenyId, @tanevId),
    (1346, 1038, null, @intezmenyId, @tanevId),
    (1347, 1039, null, @intezmenyId, @tanevId),
    (1348, 1040, null, @intezmenyId, @tanevId),
    (1349, 1041, null, @intezmenyId, @tanevId),
    (1349, 1069, null, @intezmenyId, @tanevId),
    (1349, 1070, null, @intezmenyId, @tanevId),
    (1349, 1071, null, @intezmenyId, @tanevId),
    (1350, 1042, null, @intezmenyId, @tanevId),
    (1362, 1044, null, @intezmenyId, @tanevId),
    (1363, 1044, null, @intezmenyId, @tanevId),
    (1363, 1058, null, @intezmenyId, @tanevId),
    (1363, 1059, null, @intezmenyId, @tanevId),
    (1363, 1072, null, @intezmenyId, @tanevId),
    (1364, 1046, null, @intezmenyId, @tanevId),
    (1365, 1047, null, @intezmenyId, @tanevId),
    (1369, 1061, null, @intezmenyId, @tanevId),
    (1371, 1064, null, @intezmenyId, @tanevId),
    (1372, 1032, null, @intezmenyId, @tanevId),
    (1373, 1051, null, @intezmenyId, @tanevId),
    (1374, 1049, null, @intezmenyId, @tanevId),
    (1375, 1050, null, @intezmenyId, @tanevId),
    (1376, 1054, null, @intezmenyId, @tanevId),
    (1377, 1055, null, @intezmenyId, @tanevId),
    (1378, 1056, null, @intezmenyId, @tanevId),
    (1379, 1057, null, @intezmenyId, @tanevId),
    (1380, 1055, null, @intezmenyId, @tanevId),
    (1381, 1056, null, @intezmenyId, @tanevId),
    (1382, 1048, null, @intezmenyId, @tanevId),
    (1382, 1060, null, @intezmenyId, @tanevId),
    (1382, 1066, null, @intezmenyId, @tanevId),
    (1382, 1073, null, @intezmenyId, @tanevId),
    (1382, 1062, null, @intezmenyId, @tanevId),
    (1383, 1063, null, @intezmenyId, @tanevId)
    
  PRINT N'Csoporttípus és foglalkozástípus összerendelésének létrehozása sikeres!'; 
  
  UPDATE T_MUNKAKORTIPUS SET C_ALKALMAZOTTMUNKAKORTIPUSID = 8384 WHERE C_ALTANEVID = @tanevId AND ID IN (
    6914,6352,6812,6361,6969,597,6375,8349,6414,6461,8351,553,7772,7773,6392,8352,6393
        ,8353,6394,6432,8354,8355,6968,7774,7775,6433,6457,6348,6460,6370,6710,598,6387,7783
        ,555,6406,6407,6408,552,6413,595,6915,6813,578,6434,6436,580,6447,6448,6449,6725,6450
        ,8736,8737,8738,8739,8740
  )
  UPDATE T_MUNKAKORTIPUS SET C_ALKALMAZOTTMUNKAKORTIPUSID = 8385 WHERE C_ALTANEVID = @tanevId AND ID IN (
    8350,566,561,563,559,584,3026,589,565,585,7356,6421,594,564,579,568,6332,6336,6337,6342
    ,6343,560,6359,6363,558,6365,633,567,6388,6378,6379,6382,583,562,6429,557,6437,6438,599
  )
  UPDATE T_MUNKAKORTIPUS SET C_ALKALMAZOTTMUNKAKORTIPUSID = 8386 WHERE C_ALTANEVID = @tanevId AND ID IN (
    6709,569,572,6404,571,586,570,590,6329,6330,6331,6333,6334,6335,6338,6339,6340,6341,639,637,6344,6345,6346
        ,6347,6349,6350,6351,6353,6354,6355,6356,6357,6358,574,6360,600,636,6362,635,6364,6366,638,6367,6368,642,6369
        ,6371,6372,6373,6374,6376,6377,6380,6381,6383,573,6384,6385,6386,6389,6390,582,581,6395,6396,6397,6398,6399,6400
        ,6401,6402,6403,591,6405,6409,6410,641,6411,577,6412,6415,6416,6418,576,6419,6420,6422,6423,6424,6425,6426,6427
        ,6428,6430,6431,6435,6439,587,588,6440,592,6441,6442,6443,6445,6446,6451,645,6453,6454,6455,6456,6458,6459,640
        ,6452,8372
  )
  
  EXEC dev.uspSetDictionaryItemsDefaultValue @intezmenyId, @tanevId
  EXEC dev.uspSetDictionaryItemsLanguage @intezmenyId, @tanevId

END
GO
